*******************************************************************************
*Decomposes income inequality into within and between municipality components,
*by country
*******************************************************************************

capture log close
clear
set mem 18000000
global thedir = "INSERT DIRECTORY FOR FINAL DATA OUTPUT HERE"
global aejfinalcode = "INSERT DIRECTORY CONTAINING DATA INPUTS HERE"
cd $aejfinalcode
log using aej_dcycntry, replace

/*Data files used as inputs:
				yearn_bolivia
				yearn_brazil
				yearn_canada
				yearn_chile
				yearn_colombia
				yearn_costarica
				yearn_ecuador
				yearn_elsalvador
				yearn_guatemala
				yearn_honduras
				yearn_mexico
				ywage_paraguay
				yearn_peru
				yearn_panama
				yearn_us
				yearn_uruguay
				yearn_venezuela 
				(These contain income and municipal population data, by country. They are
						produced by the file aej_yearn.do)
						
Data files produced as final product (will be input into the Matlab file aej_inequality.m): 
			ytotal.txt
*/

/* ***---Note: You must download and install the Stata add-on module
	ineqdeco to run this file. Type ssc install ineqdeco from the Stata command
	line or see http://ideas.repec.org/c/boc/bocode/s366002.html
	
	Stephen P. Jenkins, 1999. "INEQDECO: Stata module to calculate inequality indices with 
	decomposition by subgroup,"  Statistical Software Components S366002, Boston College 
	Department of Economics, revised 26 May 2008.
*/

/* ***---Note: This file decomposes income inequality in the Americas into
		inequality across municipalities and inequality within municipalities, by country. 
		The output of this file is used as input into the Matlab file inequality.m, 
		which further decomposes total inequality (at the overall Americas level) into 
		cross-country, cross-municipality, and within-municipality inequality. The output 
		file ytotal.txt also contains the country-by-country decompositions that are 
		reported in Appendix Table A3.
*/

**************************************
****--------Equal population weights
**************************************

use yearn_bolivia, clear
append using yearn_brazil
append using yearn_canada
append using yearn_chile
append using yearn_colombia
append using yearn_costarica
append using yearn_ecuador
append using yearn_elsalvador
append using yearn_guatemala
append using yearn_honduras
append using yearn_mexico
append using ywage_paraguay
append using yearn_peru
append using yearn_panama
append using yearn_us
append using yearn_uruguay
append using yearn_venezuela
keep admin1 admin2 admin3 cntry yepcip ww 

replace admin2=0 if admin2==.
replace admin3=0 if admin3==.
encode cntry, g(ccnum)
tab ccnum

gen munic=100000*admin1+admin3
replace munic=10000*admin1+100*admin2 + admin3 if cntry=="PE"

save merged_ydata, replace

*Decomposition of inequality between municipalities 

foreach X of num 1/17 {
	 use merged_ydata, clear
	 keep if ccnum==`X'
	 gen id=`X'
   ineqdeco yepcip [aw=ww], bygroup(munic)
   gen geb0y=r(between_ge0)
   gen gew0y=r(within_ge0)
	 gen get0y=r(ge0)
	 gen geb1y=r(between_ge1)
   gen gew1y=r(within_ge1)
	 gen get1y=r(ge1)
	 gen p90p50y=r(p90p50)
	 gen p90p10y=r(p90p10)
   replace yepcip=ln(yepcip)
	 summ yepcip [aw=ww]
	 gen se_yepcip=r(Var)
   replace yepcip=exp(yepcip)	 
	 summ yepcip [aw=ww]
	 gen mean_yepcip=r(mean)
	 collapse (mean) ge* se* p90* id mean*
	 saveold cntry_decomp`X', replace
}

use cntry_decomp1, clear
foreach X of num 2/17 {
	append using cntry_decomp`X'
}


*re-order so that municipality geo-referenced countires 
*and region geo-referenced countries grouped together
*(with municipality countries given lower numbers), for
*easy manipulation in matlab

gen cnum=.
replace cnum=	1	if id==	1
replace cnum=	2	if id==	2
replace cnum=	12	if id==	3
replace cnum=	13	if id==	4
replace cnum=	14	if id==	5
replace cnum=	15	if id==	6
replace cnum=	16	if id==	7
replace cnum=	3	if id==	8
replace cnum=	4	if id==	9
replace cnum=	5	if id==	10
replace cnum=	6	if id==	11
replace cnum=	8	if id==	12
replace cnum=	9	if id==	13
replace cnum=	7	if id==	14
replace cnum=	10	if id==	15
replace cnum=	17	if id==	16
replace cnum=	11	if id==	17
sort cnum
drop id
saveold $thedir/aej_cntry_decomp, replace

*add country populations that will need for weighting in the 
*decompositions in matlab (taken from the 2000 Penn World Tables)

gen nj=.
replace nj=	8.15262	if cnum==	1
replace nj=	175.552771	if cnum==	2
replace nj=	6.122515	if cnum==	3
replace nj=	12.820296	if cnum==	4
replace nj=	6.200898	if cnum==	5
replace nj=	100.0879	if cnum==	6
replace nj=	2.836298	if cnum==	7
replace nj=	5.585828	if cnum==	8
replace nj=	27.012899	if cnum==	9
replace nj=	284.1537	if cnum==	10
replace nj=	23.542649	if cnum==	11
replace nj=	30.68904	if cnum==	12
replace nj=	15.153797	if cnum==	13
replace nj=	39.685655	if cnum==	14
replace nj=	3.710558	if cnum==	15
replace nj=	12.920092	if cnum==	16
replace nj=	3.334074	if cnum==	17

gen nj_eq=1 /*for equal population weights*/

outsheet cnum mean_yepcip	geb0	gew0y	get0y	geb1y	gew1y	get1y	nj nj_eq /*
*/ using $thedir/ytotal.txt, nonames noquote nolabel replace







