***********************************************************************************
*Extracts income and demographic data and merges it with population data
***********************************************************************************

capture log close
clear
set mem 700000
global aejfinalcode = "INSERT DIRECTORY FOR FINAL OUTPUT HERE"
log using aej_yearn, replace

*--Descriptions of input files and output files given country-by-country

************************
*Bolivia (ECH 2002)
************************

global thebulkdir = "INSERT DIRECTORY WITH DATA FILES FOR BL HERE"
cd $thebulkdir

/*Data files used
		Individuos.dta
		Hogar.dta
		
*Data files created as final product
		yearn_bolivia
*/


*--get geographic id's
use Hogar, clear
keep folio id04 id02 id01

*gen a 2nd level admin identifier
gen admin3=id02
tab admin3

*gen a 1st level admin identifier
gen admin1=id01
tab admin1

keep folio admin1 admin3
tostring folio, replace
sort folio
save geo_ids, replace

*Extract income data
use Individuos, clear
 
keep folio nro1 ylabf s102 s103 s402a s402b
label drop _all

*convert to constant reference period
replace ylabf=ylabf*12

*give vars consistent names 
rename ylabf incearn
rename nro1 pernum

rename s102 male
rename s103 age

*create dummy (1=male, 0=female)
recode male (2=0)

*years of schooling


/*
s402a	cual fue el nivel de instruccion - highest level of schooling
s402b	cual fue el curso o grado de instruccion - years of schooling obtained at that level, code 8 (titulado)
 implies that a degree was received

s402a:
11	ninguno = 0
12	curso de alfabetizacin = 1
13	educacin pre-escolar = 0
14	bsico (1 a 5 aos) = years listed (equivalent to elementary school)
15	intermedio (1 a 3 aos) = years listed (first part of elementary)
16	medio (1 a 4 aos) = years listed (first part of elementary)
17	primaria (1 a 8 aos) = years listed (equivalent to elementary and middle school)
18	secundaria (1 a 4 aos) = 8 (basic schooling) + years listed (secondary schooling)
19	educacin bsica de adultos (eba) = 12
20	centro de educacin media de adultos (cema) = 12
21	normal = 12 (elementary and secondary) +years listed ("titulado"=4)
22	universidad  pblica (licenciatura) = 12 (elementary and secondary) +years listed ("titulado"=5)
23	universidad  privada (licenciatura) = 12 (elementary and secondary) +years listed ("titulado"=5)
24	postgrado, maestra = 17(elementary, secondary, & university) +years listed
25	tcnico de universidad = 12 (elementary and secondary) +years listed ("titulado"=4)
26	tcnico de instituto = 12 (elementary and secondary) +years listed 
27	institutos de formacin militar y policial = 12 (elementary and secondary) +years listed 
28	otros cursos = 12 (elementary and secondary) +years listed 
*/

*s402b is coded in years, except for the code 8, which indicates that a degree was received for the terciary
*education categories. Recode s402b so that expressed in terms of years received at the level of schooling
*given by s402a for all categories (primary, secondary, terciary) of s402a

replace s402b=4 if (s402b==8 & s402a==21)
replace s402b=5 if (s402b==8 & s402a==22)
replace s402b=5 if (s402b==8 & s402a==23)
replace s402b=4 if (s402b==8 & s402a==25)
replace s402b=4 if (s402b==8 & s402a==26)
replace s402b=5 if (s402b==8 & s402a==27)

*now create a years of schooling variable

gen educ=s402b

replace educ=8+s402b if s402a==18
replace educ=12 if s402a==19
replace educ=12 if s402a==20
replace educ=12+s402b if s402a==21
replace educ=12+s402b if s402a==22
replace educ=12+s402b if s402a==23
replace educ=17+s402b if s402a==24
replace educ=12+s402b if s402a==25
replace educ=12+s402b if s402a==26
replace educ=12+s402b if s402a==27
replace educ=12+s402b if s402a==28
summ educ, detail

keep educ male age incearn pernum folio
tostring folio, replace

sort folio
merge folio using geo_ids, uniqusing
tab _merge
drop _merge

sort folio
save temp, replace

*get sampling weights
use Hogar, clear
tostring folio, replace
keep folio factor
sort folio
merge folio using temp, uniqmaster
tab _merge
drop _merge

sort admin1

***------------Labor Income Aggregate

keep if incearn!=.
keep if incearn>0

*MEASURE 1: calculate income measures in local prices

rename incearn yepclp
summ yepclp, detail
label var yepclp "earned income - 2002 local prices"

*MEASURE 2: benchmark to PWT (international $)

/*Notes:

*I benchmark income from the census to GDP per worker in constant international $ from
the PWT, using rgdpwok (constant 2000 international $)
*/

*adjust for growth rate of income per worker between 2002 and 2003 

replace yepclp=yepclp*(1+0.0058)

*Calculate conversion factor (need to use sampling weights)

gen double ytpcnpXfactor=yepclp*factor
egen conspctot=sum(ytpcnpXfactor) 
egen wtot=sum(factor)
gen conspcbar=conspctot/wtot
drop conspctot wtot ytpcnpXfactor
summ conspcbar

gen convertgdp=(7256.0465)/conspcbar
summ convertgdp

gen yepcip=yepclp*convertgdp
summ yepcip, detail

drop convertgdp conspcbar

*label vars
label var yepcip "earned income - international dollars"
label var folio "household id" 
label var admin1 "department"
label var admin3 "district"
label var factor "sampling weight"
label var pernum "person identifier"
label var educ "years of schooling"
label var male "male=1, female=0"
label var age "age (years)"

sort admin1 admin3
merge admin1 admin3 using $aejfinalcode/pop00BL, uniqusing
tab _merge
drop if _merge==2 /*in gis, not in sample*/
drop _merge

/*fix obs. with missing population data - these munics. appear in the survey but do not
 appear in the gis map because they split after the map was made. Replace with the median population for the first level 
	admin unit*/

	
egen popbar=median(pop00), by(admin1)
replace pop00=popbar if pop00==.
drop popbar

sort admin1 admin3
save temp, replace

*generate municipality weights
gen obs=1
collapse (sum) obs (mean) pop00, by(admin1 admin3)
egen double total=sum(pop00)

gen ww=1000*((pop00/obs)/total)
keep ww admin1 admin3 obs
sort admin1 admin3 
merge admin1 admin3 using temp, uniqmaster
tab _merge
drop _merge
sum ww

*generate country ID
gen cntry="BL"

d
summ
sort folio
save $aejfinalcode/yearn_bolivia, replace

***********************************************************************************
*Brazil (6% PUMS, 2000 Brazilian census)
***********************************************************************************

global thebulkdir = "INSERT DIRECTORY WITH DATA FILES FOR BR HERE"
cd $thebulkdir

/*Data files used
	BRcensus		
*Data files created as final product
	y_brazil
*/

		
************************
*Prepare Income Data
************************
use BRcensus, clear

keep statebr munibr pernum incearn wtper yrschl age sex serial pernum

*give variables more descriptive names
rename statebr admin1
rename munibr admin3
rename wtper factor


*----recode missing values

recode incearn (99999998=.) (99999999=.)
summ incearn, detail

recode yrschl (95=.) (98=.) (99=.)
label var yrschl "years of schooling"
summ yrschl, detail
rename yrschl educ

recode sex (2=0) (9=.)
rename sex male


*----convert to annual reference period

replace incearn=incearn*12

***------------Labor Income Aggregate

keep if incearn!=.
keep if incearn>0

*MEASURE 1: calculate income measures in local prices

rename incearn yepclp
summ yepclp, detail
label var yepclp "earned income - 2000 local prices"

*MEASURE 2: benchmark to PWT (international $)

/*Notes:

*I benchmark income from the census to GDP per worker in constant international $ from
the PWT, using rgdpwok (constant 2000 international $)
*/

*adjust for growth rate of income per worker between 2000 and 2003 (economy shrank slightly)

replace yepclp=yepclp*(1-0.00055)

*Calculate conversion factor (need to use sampling weights)

gen double ytpcnpXfactor=yepclp*factor
egen conspctot=sum(ytpcnpXfactor) 
egen wtot=sum(factor)
gen conspcbar=conspctot/wtot
drop conspctot wtot ytpcnpXfactor
summ conspcbar

gen convertgdp=(15461.57218)/conspcbar
summ convertgdp

gen yepcip=yepclp*convertgdp
summ yepcip, detail
label var yepcip "earned income - international dollars"

drop convertgdp conspcbar

label drop _all

label var admin1 "state identifier"
label var admin3 "municipality identifier"
label var male "1=male, 0=female"

***some newly formed municipalilities in the census
*don't appear in my GIS map, and some small coastal
*ones aren't covered by the GIS population data. Recode them as the 
*99999 category for the respective state (99999=municipalities
*with low populations that are grouped together by state
*for confidentiality reasons)

replace admin3=	1199999	if admin3==	1100015
replace admin3=	1699999	if admin3==	1600279
replace admin3=	2199999	if admin3==	2100907
replace admin3=	2499999	if admin3==	2403251
replace admin3=	2599999	if admin3==	2503209
replace admin3=	2699999	if admin3==	2609600
replace admin3=	2999999	if admin3==	2900801
replace admin3=	2999999	if admin3==	2917300
replace admin3=	4199999	if admin3==	4113205
replace admin3=	4399999	if admin3==	4318507
replace admin3=	5199999	if admin3==	5107925

sort admin1 admin3
merge admin1 admin3 using $aejfinalcode/pop00BR, uniqusing
tab _merge
drop _merge

sort admin1 admin3
save temp, replace

*generate municipality weights
gen obs=1
collapse (sum) obs (mean) pop00, by(admin1 admin3)
egen double total=sum(pop00)

gen ww=1000*((pop00/obs)/total)
keep ww admin1 admin3 obs
sort admin1 admin3 
merge admin1 admin3 using temp, uniqmaster
tab _merge
drop _merge
sum ww
label var ww "weights"

*generate country ID
gen cntry="BR"

d
summ

sort serial pernum
save $aejfinalcode/yearn_brazil, replace


***********************************************************************************
*Canada (2.5% PUMS of the 2001 Canadian census)
***********************************************************************************

global thebulkdir = "INSERT DIRECTORY WITH DATA FILES FOR CA HERE"
cd $thebulkdir

cd $thebulkdir

/*Data files used
		canada_pums01
		
*Data files created as final product
		yearn_canada
*/

		
*Prepare Income Data

use canada_pums01, clear
label drop _all 

*give variables more descriptive names
rename provca admin1
rename wtper factor
rename sex male

recode male (2=0) (9=0)
label var male "1=male, 0=female"

rename edattand educ
recode educ (0=.) (100=0) (110=0) (120=2) (130=4) (211=5) (212=6) (221=9) (222=9) (311=13) (312=14) /*
	*/ (320=13) (321=13) (322=14) (400=17) (999=.) 

*----recode missing values
recode incearn (99999998=.) (99999999=.)


***------------Labor Income Aggregate

keep if incearn!=.
keep if incearn>0
drop incwage

*MEASURE 1: calculate income measures in local prices

rename incearn yepclp
summ yepclp, detail
label var yepclp "earned income - 2001 local prices"


*MEASURE 2: benchmark to PWT (international $)

/*Notes:

*I benchmark income from the census to GDP per worker in constant international $ from
the PWT, using rgdpwok (constant 2000 international $)
*/

*adjust for growth rate of income per worker between 2001 and 2003 

replace yepclp=yepclp*(1+0.0336)

*Calculate conversion factor (need to use sampling weights)

gen double ytpcnpXfactor=yepclp*factor
egen conspctot=sum(ytpcnpXfactor) 
egen wtot=sum(factor)
gen conspcbar=conspctot/wtot
drop conspctot wtot ytpcnpXfactor
summ conspcbar

gen convertgdp=(50082.34237)/conspcbar
summ convertgdp

gen yepcip=yepclp*convertgdp
summ yepcip, detail

drop convertgdp consp

label var yepcip "earned income - international dollars"
label var admin1 "province identifier"

keep serial pernum admin1 factor age male educ yepclp yepcip

sort admin1
merge admin1 using $aejfinalcode/pop00CA, uniqusing
tab _merge
drop _merge

sort admin1
save temp, replace

*generate municipality weights
gen obs=1
collapse (sum) obs (mean) pop00, by(admin1)
egen double total=sum(pop00)

gen ww=1000*((pop00/obs)/total)
keep ww admin1 obs
sort admin1 
merge admin1 using temp, uniqmaster
tab _merge
drop _merge
sum ww
label var ww "weights"

*generate country ID
gen cntry="CA"

d
summ
sort pernum
save $aejfinalcode/yearn_canada, replace


***********************************************************************************
*Chile (EPF 2006-2007)
***********************************************************************************

global thebulkdir = "INSERT DIRECTORY WITH DATA FILES FOR CI HERE"
cd $thebulkdir


/*Data files used
		Gastos_Hogares_Nacional_Real.dta
		personas.dta
		
*Data files created as final product
		yearn_chile.dta
*/

*get geo ids
use Gastos_Hogares_Nacional_Real.dta, clear
keep folio	region
gen admin1=.
replace admin1=1 if region=="GS" /*Greater Santiago*/
replace admin1=2 if region=="RC" /*Rest of Chile*/
collapse (mean) admin1, by(folio)
tab admin1
save geo_ids, replace

*Prepare Income Data

use personas, clear

*give variables better names

rename in~_dependiente incwage
label var incwage "salary/wage income"
rename in~ndependiente yind
egen incearn=rowtotal (incwage yind) /*wage + self-employment income*/
rename clave_hogar folio
rename numero_persona pernum
rename factor_anual factor

*prepare gender and age vars
gen male=sexo
recode male (2=0)
label var male "male=1, female=0"

gen age=.
replace age=	2	if grupo_edad==	1
replace age=	7	if grupo_edad==	2
replace age=	12	if grupo_edad==	3
replace age=	17	if grupo_edad==	4
replace age=22 if grupo_edad==5
replace age=27 if grupo_edad==6
replace age=32 if grupo_edad==7
replace age=37 if grupo_edad==8
replace age=42 if grupo_edad==9
replace age=47 if grupo_edad==10
replace age=52 if grupo_edad==11
replace age=	57	if grupo_edad==	12
replace age=	62	if grupo_edad==	13
replace age=	67	if grupo_edad==	14
replace age=	72	if grupo_edad==	15
replace age=	75	if grupo_edad==	16
label var age "age (years)"

*prepare education (by category)
rename educacion educ
/*educacion:
1  "Nunca Asistio" 2    "Sala Cuna o Jardin Infantil" 
	 3       "Kinder" 4       "Cursando Kinder" 5       "Basica o Primaria" 
 6       "Educacion Diferencial" 7       "Cursando Primero Basico" 8  "Media Comun" 
 9       "Media Tecnico Profesional" 10      "Humanidades" 11      "Normalista" 
 12      "Centro de Formacion Tecnica" 13      "Instituto Profesional" 14  "Universitario"
98 "not available" */
recode educ (98=.)
label var educ "education category"

keep incearn folio factor pernum educ age male

*convert to constant reference period
replace incearn=incearn*12

*get geographic identifiers
sort folio
merge folio using geo_ids, uniqusing
tab _merge
drop _merge
keep if admin1<.

label var folio "household id"
label var admin1 "Santiago v. non-Santiago"
label var factor "sampling weight" 

sort folio


***------------Labor Income Aggregate

keep if incearn!=.
keep if incearn>0

*Note that data in local prices are unavailable, as adjustments for regional purchasing
*power were made by the National Statistics Agency before the data were released

*MEASURE 1: calculate income measures in national prices

rename incearn yepcnp
summ yepcnp, detail
label var yepcnp "earned income - 2006 national prices"

*MEASURE 2: benchmark to PWT (international $)

/*Notes:

*I benchmark income from the census to GDP per worker in constant international $ from
the PWT, using rgdpwok (constant 2000 international $)
*/

*adjust for growth rate of income per worker between 2006 and 2003 

replace yepcnp=yepcnp*(1-0.1228)

*Calculate conversion factor (need to use sampling weights)

gen double ytpcnpXfactor=yepcnp*factor
egen conspctot=sum(ytpcnpXfactor) 
egen wtot=sum(factor)
gen conspcbar=conspctot/wtot
drop conspctot wtot ytpcnpXfactor
summ conspcbar

gen convertgdp=(28929.14567)/conspcbar
summ convertgdp

gen yepcip=yepcnp*convertgdp
summ yepcip, detail
label var yepcip "earned income - international dollars"

drop convertgdp conspcbar

label drop _all
label var admin1 "Santiago/not Santiago"

sort admin1
merge admin1 using $aejfinalcode/pop00CI, uniqusing
tab _merge
drop if _merge==2 /*in gis, not in sample*/
drop _merge

sort admin1
save temp, replace

*generate municipality weights
gen obs=1
collapse (sum) obs (mean) pop00, by(admin1)
egen double total=sum(pop00)

gen ww=1000*((pop00/obs)/total)
keep ww admin1 obs
sort admin1 
merge admin1 using temp, uniqmaster
tab _merge
drop _merge
sum ww

*generate country ID
gen cntry="CI"

d
summ
sort folio
save $aejfinalcode/yearn_chile, replace


***********************************************************************************
****Colombia (Encuesta de Calidad de Vida 2003)
***********************************************************************************

global thebulkdir = "INSERT DIRECTORY WITH DATA FILES FOR CO HERE"
cd $thebulkdir


/*Data files used
		personas
		educa
		trabajo
		
*Data files created as final product
		yearn_colombia
*/

*Prepare age and gender data

use personas, clear
rename numero folio
destring e02, replace
rename e02 age
label var age "age (years)"

destring e03, replace
rename e03 male
recode male (2=0)
label var male "1=male, 0=female"

rename e01 pernum
keep folio pernum age male
sort folio pernum
save temp, replace

*Prepare education data

use educa, clear

rename fex factor 
rename numero folio
rename e01 pernum
rename region admin1
destring i01, replace
recode i01 (2=0)

destring i0401, replace
destring i0402, replace
gen educ=.
replace educ=0 if (i0401==1 | i0401==2)
replace educ=i0402 if (i0401==3)
replace educ=5+i0402 if (i0401==4)
replace educ=13+i0402 if (i0401>=5 & i0401<=8)
replace educ=17+i0402 if (i0401>=9 & i0401<=10)

/*i0401
Ninguno 1.
Preescolar 2.
Bsica Primaria (1 a 5) 3.
Bsica secundaria y media (6 a 13) 4.
Tcnico 5.
Tecnolgico 6.
Universitaria sin ttulo 7.
Universitaria con ttulo 8.
Postgrado sin ttulo 9.
Postgrado con ttulo 10.
*/
tab educ
label var educ "years of education"
keep if (educ<.)

keep admin1 folio factor pernum educ 
sort folio pernum
mmerge folio pernum using temp, type(1:1)
drop _merge
sort folio pernum
save temp, replace


*Prepare Income Data

use trabajo, clear

*the employment sectin of the survey does not allow us to separate wage/salary income
*from labor income, and thus we are only able to estimate labor income. The following
*aggregates the various potential components of labor income (salary, subsidy to housing, 
*childcare, transport, etc)

foreach X in l23 l2402 l2502 l2602 l2702 l2802 l2902 l3002 l3102 l3202 {
	destring `X', replace
	summ `X'
	replace `X'=`X'*12 /*annual reference period*/
}                   

egen double incearn=rowtotal(l23 l2402 l2502 l2602 l2702 l2802 l2902 l3002 l3102 l3202)
summ incearn, detail
rename fex factor 
rename numero folio
rename e01 pernum
rename region admin1
keep admin1 folio factor incearn pernum

sort folio pernum
mmerge folio pernum using temp, type(1:1)
drop _merge
keep if incearn!=.
keep if incearn>0

*MEASURE 1: calculate income measures in local prices

rename incearn yepclp
summ yepclp, detail
label var yepclp "earned income - 2003 local prices"

*MEASURE 2: benchmark to PWT (international $)

/*Notes:

*I benchmark income from the census to GDP per worker in constant international $ from
the PWT, using rgdpwok (constant 2000 international $)
*/

*survey conducted in base year

*Calculate conversion factor (need to use sampling weights)

gen double ytpcnpXfactor=yepclp*factor
egen conspctot=sum(ytpcnpXfactor) 
egen wtot=sum(factor)
gen conspcbar=conspctot/wtot
drop conspctot wtot ytpcnpXfactor
summ conspcbar

gen convertgdp=(13759.36248)/conspcbar
summ convertgdp

gen yepcip=yepclp*convertgdp
summ yepcip, detail
label var yepcip "earned income - international dollars"

drop convertgdp conspcbar
destring admin1, replace
label var admin1 "region"
label var folio "household identifier"
label var pernum "person identifier"
label var factor "sampling weight"


sort admin1
merge admin1 using $aejfinalcode/pop00CO, uniqusing
tab _merge
drop _merge

sort admin1
save temp, replace

*generate municipality weights
gen obs=1
collapse (sum) obs (mean) pop00, by(admin1)
egen double total=sum(pop00)

gen ww=1000*((pop00/obs)/total)
keep ww admin1 obs
sort admin1 
merge admin1 using temp, uniqmaster
tab _merge
drop _merge
sum ww

*generate country ID
gen cntry="CO"

d
summ
sort folio
save $aejfinalcode/yearn_colombia, replace


***********************************************************************************
*Costa Rica (2004)
***********************************************************************************

global thebulkdir = "INSERT DIRECTORY WITH DATA FILES FOR CR HERE"
cd $thebulkdir


/*Data files used
		cr04db03
		
*Data files created as final product
		yearn_costarica
*/

		
************************
*Prepare Income Data
************************

/*Note - We do not merge these data with the demographic and education data because
 	   the accompanying education data were not available in the dataset that we
 	   purchased, hence we are not able to include Costa Rica in our Mincer decompositions*/
 	   
*get income data

use cr04db03.dta, clear
gen double folio=hogar+10*vivienda+1000*segmento
tostring folio, replace

*give variables more descriptive names
rename yasefb incwage
rename yindtot yind
replace yind=0 if yind<0
egen incearn=rowtotal(incwage yind) /*salaried income + self employment income*/
rename nroinfor pernum
rename region admin1
rename factorex factor

keep folio incearn pernum admin1 factor

label var folio "household identifier"
label var pernum "person identifier"
label var factor "sampling weight"
label var admin1 "geographic region"

summ incearn, detail

*convert to annual reference period
replace incearn=incearn*12
sort admin1

***------------Labor Income Aggregate

keep if incearn!=.
keep if incearn>0

*MEASURE 1: calculate income measures in local prices

rename incearn yepclp
summ yepclp, detail
label var yepclp "earned income - 2004 local prices"

*MEASURE 2: benchmark to PWT (international $)

/*Notes:

*I benchmark income from the census to GDP per worker in constant international $ from
the PWT, using rgdpwok (constant 2000 international $)
*/

*adjust for growth rate of income per worker between 2004 and 2003 

replace yepclp=yepclp*(1-0.0256)

*Calculate conversion factor (need to use sampling weights)

gen double ytpcnpXfactor=yepclp*factor
egen conspctot=sum(ytpcnpXfactor) 
egen wtot=sum(factor)
gen conspcbar=conspctot/wtot
drop conspctot wtot ytpcnpXfactor
summ conspcbar

gen convertgdp=(20949.29948)/conspcbar
summ convertgdp

gen yepcip=yepclp*convertgdp
summ yepcip, detail
label var yepcip "earned income income - international dollars"

drop convertgdp conspcbar

*note - the data are geo-referenced to six geographic regions, for which there 
*are not GIS boundaries. We assume each region has equal population in constructing
*the weights. 

gen obs=1
egen temp=sum(obs)
gen ww=1000/temp
drop temp obs
gen temp=1
egen double obs=sum( temp), by(admin1)
drop temp
label var ww "weights"

gen cntry="CR"
d
sort folio
save $aejfinalcode/yearn_costarica, replace


***********************************************************************************
***Ecuador (ECV 2005)
***********************************************************************************

global thebulkdir = "INSERT DIRECTORY WITH DATA FILES FOR EC HERE"
cd $thebulkdir


/*Data files used
	e5r_per	
*Data files created as final product
	yearn_ecuador
*/

**Get income and demographic data
/*INCOME QUESTIONS
***primary employment
pa22a. ingresos como independiente 
pa22c. veces que recibe al ao 
pa23a. salario o jornal 
pa23b. frecuencia del salario o jornal 
pa28b. ingresos x aniversario
pa30b. bono vacacional
pa30d. aguinaldo de navidad
pa30f. monto de las utilidades
pa33b. gasto estimado en serv.guardera al mes
pa35. sueldo sin descuentos
pa36b. monto del dcimo tercer sueldo
pa38b. monto de horas extras al mes
pa39b. monto de comisiones propinas al mes
pa40b. cuanto cuesta los alimentos
pa40c. cada cuanto recibe los alimentos
pa41b. cunto pagara x la vivienda al mes
pa42b. cunto vale la ropa de trabajo
pa42c. al ao veces que recibe la ropa

***secondary employment
pa51. meses que trabajo ult. 12 meses
pa56a. ingresos independiente
pa56c. veces que tuvo ingr.indep. en el ao
pa57a. salario o jornal
pa57b. cada cuanto le pagan salario o jornal
pa58. sueldo o salario total sin descuentos
pa59b. mnto del dcimo tercer sueldo
pa61b. monto de comisiones propinas
pa62b. monto estimado al mes x alimentos, ropa,..
*/

use $thebulkdir/ECV2005/e5r_per.dta, clear
gen folio=ciudad+zona+sector+vivienda+hogar
label var folio "household identifier"

rename factor_f factor
label var factor "sampling weight"

rename persona pernum
label var pernum "individual identifier"

*recode missing values
foreach X in pa22a pa22c pa23a pa23b pa28b pa30b pa30d pa30f pa35 pa36b pa38b pa39b pa40b /*
*/ pa40c pa41b pa42b pa42c pa51 pa56a pa56c pa57a pa57b pa58 pa59b pa61b pa62b {
	recode `X'  ( 999999=.) (99=.)
	summ `X'
}

*calculate varous income sub-components
gen self1=pa22a*pa22c /*primary occ. self-employment earnings* times/year received*/
summ self1, detail

recode pa23b (1=261) (2=52) (3=24) (4=12)
gen wage1=pa23a*pa23b*(pa17/12) /*primary occ wage earnings*frequency*percentage of year that worked*/
summ wage1, detail

replace pa35=pa35*12
egen salary1=rowtotal(pa35 pa36b) /*monthly salary and bonus*/
summ salary1, detail

*various income from other sources - overtime, tips, food in-kind, housing in-kind, etc. 

foreach X in pa33b pa38b pa39b pa41b {
	replace `X'=`X'*12
}

recode pa40c (1=261) (2=52) (3=24) (4=12)
replace pa40b= pa40b* pa40c

replace pa42b=pa42b*pa42c

egen other1=rowtotal(pa28b pa30b pa30d pa30f pa33b pa38b pa39b pa41b pa42b pa40b)
summ other1, detail

gen self2=pa56c*pa56a /*mos. recieved*secondary occ. self-employment earnings/month*/
summ self2, detail

recode pa57b (1=261) (2=52) (3=24) (4=12)
gen wage2=pa57a*pa57b*(pa51/12) /*secondary occ. wage earnings*frequency*percentage of year that worked*/
summ wage2, detail

replace pa58=pa58*12
egen salary2=rowtotal(pa35 pa36b) /*monthly salary and bonus*/
summ salary2, detail

foreach X in pa61b pa62b {
	replace `X'=`X'*12
}

egen other2=rowtotal(pa61b pa62b)
summ other2, detail

egen incwage=rowtotal(wage1 wage2 salary1 salary2 other1 other2)
summ incwage, detail
    
egen incearn=rowtotal(incwage self1 self2)
summ incearn, detail

gen admin1=substr(ciudad, 1, 2)

*get gender and age variables
gen male=sexo
recode male (2=0)
label var male "male=1, female=0"

rename edad age
label var age "age (years)"

*get education
gen educ=.
recode pe46 (99=.)
replace educ=0 if (pe45==1 | pe45==2 | pe45==3) /*none, pre-school, etc*/
replace educ=pe46 if (pe45==4) /*elementary*/
replace educ=pe46+6 if (pe45==5 | pe45==6) /*jr. high, secondary*/
replace educ=pe46+9 if (pe45==7) /*post jr. high*/
replace educ=pe46+12 if (pe45==8) /*university*/
replace educ=pe46+16 if (pe45==9) /*post-grad*/
label var educ "years of schooling" 
summ educ, detail


keep admin1 folio pernum factor incearn male age educ


***------------Labor Income Aggregate

keep if incearn!=.
keep if incearn>0

*MEASURE 1: calculate income measures in local prices

rename incearn yepclp
summ yepclp, detail
label var yepclp "earned income - 2005 local prices"

*MEASURE 2: benchmark to PWT (international $)

/*Notes:

*I benchmark income from the census to GDP per worker in constant international $ from
the PWT, using rgdpwok (constant 2000 international $)
*/

*adjust for growth rate of income per worker between 2005 and 2003 

replace yepclp=yepclp*(1-0.0976)

*Calculate conversion factor (need to use sampling weights)

gen double ytpcnpXfactor=yepclp*factor
egen conspctot=sum(ytpcnpXfactor) 
egen wtot=sum(factor)
gen conspcbar=conspctot/wtot
drop conspctot wtot ytpcnpXfactor
summ conspcbar

gen convertgdp=(10704.37365)/conspcbar
summ convertgdp

gen yepcip=yepclp*convertgdp
summ yepcip, detail
label var yepcip "earned income - international dollars"

drop convertgdp conspcbar

label var folio "household identifier"

destring admin1, replace
label var admin1 "province"


sort admin1
merge admin1 using $aejfinalcode/pop00EC, uniqusing
tab _merge
keep if _merge==3 /*code 23 = disputed territories with Peru, in map but not
	in survey; 22=Galapagos Islands, in survey but I don't have population data*/
drop if _merge==2 /*in gis, not in sample*/
drop _merge

sort admin1
save temp, replace

*generate municipality weights
gen obs=1
collapse (sum) obs (mean) pop00, by(admin1)
egen double total=sum(pop00)

gen ww=1000*((pop00/obs)/total)
keep ww admin1 obs
sort admin1 
merge admin1 using temp, uniqmaster
tab _merge
drop _merge
sum ww
label var ww "weights"

*generate country ID
gen cntry="EC"

d
summ
sort folio
save $aejfinalcode/yearn_ecuador, replace


***********************************************************************************
*El Salvador (2006)
***********************************************************************************


global thebulkdir = "INSERT DIRECTORY WITH DATA FILES FOR ES HERE"
cd $thebulkdir


/*Data files used
		sec00
		sec04
		sec05
		
*Data files created as final product
		yearn_elsalvador
*/

		
*Prepare Income Data

**---get geographic and other identifiers

use sec00, clear
gen temp=viv+10*folio+1000000*tipo
tostring temp, replace
drop folio
rename temp folio
rename r004 admin1
rename r005 admin3
rename area urban
recode urban (2=0)
tab admin1
tab admin3
keep folio admin1 admin3 urban 
sort folio
save geo_ids, replace

*get sampling weights

use sec00, clear
gen temp=viv+10*folio+1000000*tipo
tostring temp, replace
drop folio
rename temp folio
rename fac00 factor 
sort folio
save factor, replace


*get age and gender variables

use sec01, clear
gen temp=viv+10*folio+1000000*tipo
tostring temp, replace
drop folio
rename temp folio

rename r106 age
label var age "age (years)"
gen male=r104
recode male (2=0)
label var male "1=male, 0=female"
rename orden pernum
keep folio pernum age male
sort folio pernum
save temp, replace

*get education
use sec02, clear
label drop _all
gen temp=viv+10*folio+1000000*tipo
tostring temp, replace
drop folio
rename temp folio

rename aproba1 educ
label var educ "years of schooling completed" 

rename r201 pernum
label var pernum "individual identifier"

rename fac02 factor
label var factor "sampling weight"

keep folio pernum factor educ 

sort folio pernum
mmerge folio pernum using temp, type(1:1)
drop _merge
sort folio pernum
save temp, replace



*get income data

use sec04, clear
gen double temp=viv+10*folio+1000000*tipo
tostring temp, replace
drop folio
rename temp folio

*recode missing values

foreach X in r423 r433 r427 r428 r430 {
	recode `X' (999999.99=.)
}


****convert relevant variables to annual reference period

*salary income from principal dependent occupation
recode r422 (1=365) (2=52) (3=24) (4=12) (5=12)
replace r423=r423*r422

*other income from principal dependent occupation

foreach X in 01 02 03 04 05 06 07 08 09 10 11 {
	recode r424`X'a (999999.99=.) (0=.)
	replace r424`X'a =r424`X'a*r424`X'b if r424`X'a!=.
}

*salary from secondary dependent occupation
replace r433=r433*12

*other income from secondary occupation
	
foreach X in 01 02 03 04 05 06 07 08 09 10 11 {
	recode r434`X'a (999999.99=.) (0=.)
	replace r434`X'a =r434`X'a*r434`X'b if r434`X'a!=.
}

*self-employment income - gross earnings and expenses
recode r426 (1=365) (2=52) (3=24) (4=12) (6=3) (7=2) (8=1) (9=12)
recode r426 (5=6)

foreach X in r427 r428 {
	replace `X'=`X'*r426
	recode `X' (.=0)
}

*slf-employment income - autoconsumption
replace r430 = r430*12
recode r430 (.=0)

rename orden pernum

sort folio pernum
mmerge folio pernum using temp, type(1:1)
drop _merge
sort folio pernum
save temp, replace

****get self-employment in agriculture income from another file
use sec05, clear
gen temp=viv+10*folio+1000000*tipo
tostring temp, replace
drop folio
rename temp folio
rename r501 pernum
keep folio pernum ingneto /*ingneto gives net earnings from ag and already has a yearly reference period*/ 
sort folio pernum
mmerge folio pernum using temp, type(1:1)
drop _merge

sort folio
merge folio using factor, uniqusing
tab _merge
drop _merge

sort folio
merge folio using geo_ids, uniqusing
tab _merge
drop _merge

***label variables

label var pernum "person identifier"
label var folio "household identifier"
label var admin1 "department"
label var admin3 "municipality"
label var factor "sampling weight" 


***Create income measures

*salary/wage income

egen incwage=rowtotal(r423 r424* r433 r434*)

*labor income

gen yself=r427-r428+r430 /*profits - expenses + autoconsumption*/
keep if yself>=0
summ yself, detail

egen incearn=rowtotal(r423 r424* r433 r434* yself ingneto)
summ incearn, detail

keep folio pernum admin* factor incearn age male educ

sort folio

***------------Labor Income Aggregate

keep if incearn!=.
keep if incearn>0

*MEASURE 1: calculate income measures in local prices

rename incearn yepclp
summ yepclp, detail
label var yepclp "earned income - 2006 local prices"


*MEASURE 2: benchmark to PWT (international $)

/*Notes:

*I benchmark income from the census to GDP per worker in constant international $ from
the PWT, using rgdpwok (constant 2000 international $)
*/

*adjust for growth rate of income per worker between 2006 and 2003 

replace yepclp=yepclp*(1-0.0478)

*Calculate conversion factor (need to use sampling weights)

gen double ytpcnpXfactor=yepclp*factor
egen conspctot=sum(ytpcnpXfactor) 
egen wtot=sum(factor)
gen conspcbar=conspctot/wtot
drop conspctot wtot ytpcnpXfactor
summ conspcbar

gen convertgdp=(10954.83465)/conspcbar
summ convertgdp

gen yepcip=yepclp*convertgdp
summ yepcip, detail
label var yepcip "earned income - international dollars"

drop convertgdp conspcbar

label var admin1 "department identifier"
label var admin3 "municipality identifier"
label var folio "household identifier"
label var pernum "person identifier"


sort admin1 admin3
merge admin1 admin3 using $aejfinalcode/pop00ES, uniqusing
tab _merge
drop if _merge==2 /*in gis, not in sample*/
drop _merge

sort admin1 admin3
save temp, replace

*generate municipality weights
gen obs=1
collapse (sum) obs (mean) pop00, by(admin1 admin3)
egen double total=sum(pop00)

gen ww=1000*((pop00/obs)/total)
keep ww admin1 admin3 obs
sort admin1 admin3 
merge admin1 admin3 using temp, uniqmaster
tab _merge
drop _merge
sum ww
label var ww "weights"

*generate country ID
gen cntry="ES"

d
summ
sort folio pernum
save $aejfinalcode/yearn_elsalvador, replace


***********************************************************************************
*Guatemala (ENCOVI2000)
***********************************************************************************

global thebulkdir = "INSERT DIRECTORY WITH DATA FILES FOR GT HERE"
cd $thebulkdir


/*Data files used
		CONSUMO5.DTA
		ECV09P05.DTA
		ECV11P10.DTA
		
*Data files created as final product
		yearn_guatemala
*/

**---get geographic and other identifiers

use CONSUMO5.DTA, clear

keep region depto mupio area hogar thogar factor
label var region "political admin region"
recode area 2=0
rename area urban
label var urban "urban"
rename hogar folio
rename thogar hhmem
label var hhmem "household members"
rename depto admin1
label var admin1 "department code"	
rename mupio admin3
label var admin3 "municipio code"
sort folio
save geo_ids, replace

*Get age and gender data

use ECV09P05.DTA, clear
rename hogar folio
gen male=sexo
recode male (2=0)
label var male "1=male, 0=female"
rename caso pernum
rename edad age
label var age "age (years)"

*get education data

/* p07b27a: Education level categories
         1 ninguno
           2 preparatoria
           3 primaria
           4 educacion media
           5 educacion superior
           6 post-grado
           7 educacion adultos
*/

gen educ=.
replace educ=0 if ( p07b27a==1)
replace educ=0 if ( p07b27a==2) /*don't count pre-school*/
replace educ=p07b27b if ( p07b27a==3)
replace educ=p07b27b+5 if ( p07b27a==4)
replace educ=p07b27b+12 if ( p07b27a==5)
replace educ=p07b27b+16 if ( p07b27a==6)
replace educ=p07b27b if ( p07b27a==7)
keep if (educ<.)
label var educ "years of schooling"
keep folio pernum age male educ
sort folio pernum
save temp, replace		


*Prepare Income Data

use ECV11P10.DTA, clear

recode p10f01 (99999=.) (99998=.) (99995=.)
recode p10f02 (99999=.) (99998=.) (99995=.)

summ p10f01 p10f02, detail

egen incearn=rowtotal(p10f01 p10f02)

replace incearn=incearn*12 /*annual reference period*/

*give variables more descriptive names
rename hogar folio
rename caso pernum

sort folio pernum
mmerge folio pernum using temp, type(1:1)
drop _merge

sort folio
merge folio using geo_ids, uniqusing
tab _merge
drop _merge

keep folio pernum factor incearn admin* age male educ

*label variables
label var factor "sampling weights"
label var folio "household id"
label var pernum "person id"
label var admin3 "municipality"
label var admin1 "department"

sort admin1

***------------Labor Income Aggregate

keep if incearn!=.
keep if incearn>0

*MEASURE 1: calculate income measures in local prices

rename incearn yepclp
summ yepclp, detail
label var yepclp "earned income - 2000 local prices"

*MEASURE 2: benchmark to PWT (international $)

/*Notes:

*I benchmark income from the census to GDP per worker in constant international $ from
the PWT, using rgdpwok (constant 2000 international $)
*/

*adjust for growth rate of income per worker between 2000 and 2003 (inc/wkr shrank during this time)

replace yepclp=yepclp*(1-0.0402)

*Calculate conversion factor (need to use sampling weights)

gen double ytpcnpXfactor=yepclp*factor
egen conspctot=sum(ytpcnpXfactor) 
egen wtot=sum(factor)
gen conspcbar=conspctot/wtot
drop conspctot wtot ytpcnpXfactor
summ conspcbar

gen convertgdp=(10190.37883)/conspcbar
summ convertgdp

gen yepcip=yepclp*convertgdp
summ yepcip, detail
label var yepcip "earned income - international dollars"

drop convertgdp conspcbar

label var admin1 "state identifier"
label var admin3 "municipality identifier"


sort admin1 admin3
merge admin1 admin3 using $aejfinalcode/pop00GT, uniqusing
tab _merge
drop if _merge==2 /*in gis, not in sample*/
drop _merge

*there are a number of what appear to be new municipalities in Guatemala
*department. Replace population with department-level median.


egen popbar=median(pop00), by(admin1)
replace pop00=popbar if pop00==.
drop popbar

sort admin1 admin3
save temp, replace

*generate municipality weights
gen obs=1
collapse (sum) obs (mean) pop00, by(admin1 admin3)
egen double total=sum(pop00)

gen ww=1000*((pop00/obs)/total)
keep ww admin1 admin3 obs
sort admin1 admin3 
merge admin1 admin3 using temp, uniqmaster
tab _merge
drop _merge
sum ww
label var ww "weights"

*generate country ID
gen cntry="GT"

d
summ
sort folio
save $aejfinalcode/yearn_guatemala, replace


***********************************************************************************
*Prepare income data from ECV 2004 Honduras
***********************************************************************************

global thebulkdir = "INSERT DIRECTORY WITH DATA FILES FOR HO HERE"
cd $thebulkdir


/*Data files used
		mecovi_st
		
*Data files created as final product
		yearn_honduras
*/

use mecovi_st, clear
 
label drop _all

*get age and gender data
rename edad age
recode age (999=.)
label var age "age (years)"

gen male=sexo
recode male (2=0)
label var male "1=male, 0=female"

*get income data
rename ytrab incearn
rename nper pernum
rename hogar folio
rename depto admin1
rename munic admin3

*annual reference period
replace incearn=incearn*12

label var folio "household identifier"
label var pernum "person identifier"
label var admin1 "department"
label var admin3 "municipality"
label var factor "sampling weights"

*get education data

gen educ=.
recode s4p37a (99=.)   
recode s4p37b (99=.)    
replace educ=0 if (s4p37a==1 | s4p37a==2 | s4p37a==3)
replace educ=s4p37b if (s4p37a==4) /*elementary*/
replace educ=s4p37b+6 if (s4p37a==5) /*junior high*/
replace educ=s4p37b+9 if (s4p37a==6) /*high school*/
replace educ=s4p37b+9 if (s4p37a==7) /*high school - technical*/
replace educ=s4p37b+12 if (s4p37a==8) /*post-secondary; non-university*/
replace educ=s4p37b+12 if (s4p37a==9) /*post-secondary; university*/
replace educ=s4p37b+16 if (s4p37a==10) /*post-grad*/
replace educ=s4p37b+16 if (s4p37a==11) /*masters*/
replace educ=s4p37b+16 if (s4p37a==12) /*PhD*/
tab educ
label var educ "years of schooling"


keep incearn folio pernum admin* factor age male educ

sort admin1
***------------Labor Income Aggregate

keep if incearn!=.
keep if incearn>0

*MEASURE 1: calculate income measures in local prices

rename incearn yepclp
summ yepclp, detail
label var yepclp "earned income - 2004 local prices"

*MEASURE 2: benchmark to PWT (international $)

/*Notes:

*I benchmark income from the census to GDP per worker in constant international $ from
the PWT, using rgdpwok (constant 2000 international $)
*/

*adjust for growth rate of income per worker between 2004 and 2003 

replace yepclp=yepclp*(1-0.0295)

*Calculate conversion factor (need to use sampling weights)

gen double ytpcnpXfactor=yepclp*factor
egen conspctot=sum(ytpcnpXfactor) 
egen wtot=sum(factor)
gen conspcbar=conspctot/wtot
drop conspctot wtot ytpcnpXfactor
summ conspcbar

gen convertgdp=(6120.953579)/conspcbar
summ convertgdp

gen yepcip=yepclp*convertgdp
summ yepcip, detail
label var yepcip "earned income - international dollars"

drop convertgdp conspcbar

label var admin1 "department identifier"
label var admin3 "municipality identifier"


sort admin1 admin3
merge admin1 admin3 using $aejfinalcode/pop00HO, uniqusing
tab _merge

**There are three municipalities, 903, 904 and 1628, that are new 
*municipalities and do not appear in my GIS data. Assign them the
*department level population median. 

egen popbar=median(pop00), by(admin1)
replace pop00=popbar if pop00==.
drop popbar

drop if _merge==2 /*2= in gis, not in sample*/
drop _merge

sort admin1 admin3
save temp, replace

*generate municipality weights
gen obs=1
collapse (sum) obs (mean) pop00, by(admin1 admin3)
egen double total=sum(pop00)

gen ww=1000*((pop00/obs)/total)
keep ww admin1 admin3 obs
sort admin1 admin3 
merge admin1 admin3 using temp, uniqmaster
tab _merge
drop _merge
sum ww
label var ww "weights"

*generate country ID
gen cntry="HO"

d
summ
sort folio
save $aejfinalcode/yearn_honduras, replace


***********************************************************************************
*Mexico (10% PUMS of the 2000 Mexican census)
***********************************************************************************

global thebulkdir = "INSERT DIRECTORY WITH DATA FILES FOR MX HERE"
cd $thebulkdir

/*Data files used
		MXcensus
		
*Data files created as final product
		yearn_mexico
*/

		

use MXcensus, clear

*give variables more descriptive names

label drop _all 
rename statemx admin1
rename munimx admin3
label var admin3 "municipality"
rename pernum folio
rename wtper factor

*----prepare education vars


replace yrschl=. if yrschl>=90
label var yrschl "years of schooling"
summ yrschl, detail
rename yrschl educ
tab educ

*prepare demographic vars
recode age (999=.)
label var age "age (years)"

recode sex (2=0) (9=.)
rename sex male
label var male "male=1, female=0"
tab male

*-------prepare income vars
recode incearn (99999998=.) (99999999=.)

summ incearn, detail
replace incearn=incearn*12
sort admin1

***------------Labor Income Aggregate

keep if incearn!=.
keep if incearn>0

*MEASURE 1: calculate income measures in local prices

rename incearn yepclp
summ yepclp, detail
label var yepclp "earned income - 2000 local prices"

*MEASURE 2: benchmark to PWT (international $)

/*Notes:

*I benchmark income from the census to GDP per worker in constant international $ from
the PWT, using rgdpwok (constant 2000 international $)
*/

*adjust for growth rate of income per worker between 2000 and 2003 (economy shrank)

replace yepclp=yepclp*(1-0.0520)

*Calculate conversion factor (need to use sampling weights)

gen double ytpcnpXfactor=yepclp*factor
egen conspctot=sum(ytpcnpXfactor) 
egen wtot=sum(factor)
gen conspcbar=conspctot/wtot
drop conspctot wtot ytpcnpXfactor
summ conspcbar

gen convertgdp=(18627.58541)/conspcbar
summ convertgdp

gen yepcip=yepclp*convertgdp
summ yepcip, detail
label var yepcip "earned income - international dollars"

drop convertgdp conspcbar

gen temp=admin3+100000
drop admin3
tostring temp, replace
gen admin3=substr(temp, 4, 3)
destring admin3, replace
drop temp

keep serial folio admin1 admin3 factor age male educ yepcip yepclp

label var admin1 "state identifier"
label var admin3 "municipality identifier"

sort admin1 admin3
merge admin1 admin3 using $aejfinalcode/pop00MX, uniqusing
tab _merge
drop if _merge==2 /*in gis, not in sample*/
drop _merge


*there are several new municipalities in the census that have not been updated
*onto the GIS map. I replace their population with the state-level median. 


egen popbar=median(pop00), by(admin1)
replace pop00=popbar if pop00==.
drop popbar

sort admin1 admin3
save temp, replace

*generate municipality weights
gen obs=1
collapse (sum) obs (mean) pop00, by(admin1 admin3)
egen double total=sum(pop00)

gen ww=1000*((pop00/obs)/total)
keep ww admin1 admin3 obs
sort admin1 admin3 
merge admin1 admin3 using temp, uniqmaster
tab _merge
drop _merge
sum ww
label var ww "weight"


*generate country ID
gen cntry="MX"

d
summ
sort folio

save $aejfinalcode/yearn_mexico, replace


***********************************************************************************
*Panama (10% PUMS of the 2000 Panama census)
***********************************************************************************

global thebulkdir = "INSERT DIRECTORY WITH DATA FILES FOR PM HERE"
cd $thebulkdir

/*Data files used
		PAcensus
		
*Data files created as final product
		yearn_panama
*/

		
************************
*Prepare Income Data
************************
use PAcensus, clear

*give variables more descriptive names

label drop _all
rename provpa admin1
rename distpa admin3
rename pernum folio
rename wtper factor
rename yrschl educ

*-prepare education variable
replace educ=. if educ>18
recode age (999=.)
label var educ "years of schooling"

*-prepare demographic variables
label var age "age (years)"
recode sex (9=.) (2=0)
rename sex male
label var male "male=1, female=0"

**-----prepare income variables

*----recode missing values

recode incearn (99999998=.) (99999999=.) ( 9997=.)

summ incearn, detail

*convert to constant refeence period
replace incearn=incearn*12
sort folio

*There are three indigenous territories - in GIS data, I can't identify municipalities
*within each of the territories, so recode so that municipalities within each indigenous
*territory have the same admin identifiers
replace admin3=1299 if (admin3==1203)

gen temp=admin3+10000
drop admin3
tostring temp, replace
gen admin3=substr(temp, 4, 2)
destring admin3, replace
tab admin3
drop temp
keep if admin1<.


sort admin1
***------------Labor Income Aggregate

keep if incearn!=.
keep if incearn>0

*MEASURE 1: calculate income measures in local prices

rename incearn yepclp
summ yepclp, detail
label var yepclp "earned income pc - 2000 local prices"


*MEASURE 3a: benchmark to PWT (international $) ***NON-REGIONALLY DEFLATED***

/*Notes:

*I benchmark income from the census to GDP per worker in constant international $ from
the PWT, using rgdpwok (constant 2000 international $)
*/

*adjust for growth rate of income per worker between 2000 and 2003 

replace yepclp=yepclp*(1+0.0365)

*Calculate conversion factor (need to use sampling weights)

gen double ytpcnpXfactor=yepclp*factor
egen conspctot=sum(ytpcnpXfactor) 
egen wtot=sum(factor)
gen conspcbar=conspctot/wtot
drop conspctot wtot ytpcnpXfactor
summ conspcbar

gen convertgdp=(19498.5603)/conspcbar
summ convertgdp

gen yepcip=yepclp*convertgdp
summ yepcip, detail
label var yepcip "earned income income - international dollars"

drop convertgdp conspcbar



label var admin1 "province"
label var admin3 "municipality"

keep serial folio admin1 admin3 factor age male educ yepclp yepcip

sort admin1 admin3
merge admin1 admin3 using $aejfinalcode/pop00PM, uniqusing
tab _merge
drop _merge

sort admin1 admin3
save temp, replace

*generate municipality weights
gen obs=1
collapse (sum) obs (mean) pop00, by(admin1 admin3)
egen double total=sum(pop00)

gen ww=1000*((pop00/obs)/total)
keep ww admin1 admin3 obs
sort admin1 admin3 
merge admin1 admin3 using temp, uniqmaster
tab _merge
drop _merge
sum ww
label var ww "weight"

*generate country ID
gen cntry="PM"

d
summ
sort folio

save $aejfinalcode/yearn_panama, replace



***********************************************************************************
*Paraguay (Encuesta Integrada de Hogares 2000/2001)
***********************************************************************************

global thebulkdir = "INSERT DIRECTORY WITH DATA FILES FOR PA HERE"
cd $thebulkdir

/*Data Files Used 	
		R01_00
		R02_00 
		R04_00

*Data Files Created as Final Product
		ywage_paraguay
*/

**There currency has very large #s, so I divide
*all local currency units by 10,000

*Get income and demographic data

*--get geographic identifiers

use R01_00, clear
gen folio=nhoga+10*nvivi+10000*upm /*unique household identifier*/
rename dpto admin1
rename dist admin3
rename barrio admin4
label var admin4 "neighborhood"
rename area urban
recode urban (6=0)
tab urban
label var urban "urban"
rename fex factor
label var factor "sampling weight"

keep folio admin* urban factor
sort folio
save geo_ids, replace


use R02_00, clear
gen folio=nhoga+10*nvivi+10000*upm /*unique household identifier*/
label var folio "household identifier"

rename fex factor
label var factor "sampling weight"

rename l02 pernum
label var pernum "individual identifier"

*get age and gender variables
gen male=p06
recode male (6=0)
label var male "male=1, female=0"

rename p02 age
label var age "age (years)"

*monetary wage/salary from primary employment
recode b13t (999999999=.)
replace b13t=b13t/10000
summ b13t, detail
gen wage1=(b13t*12)

*additional salary (i.e. overtime) from primary employment
recode b15u (3=52) (4=24) (5=12) (6=1) (9=.) (0=.)
recode b15g (999999999=.)
replace b15g=b15g/10000
summ b15g, detail
gen extra1=(b15u*b15g)
summ extra1, detail

*payment in kind (food, housing, clothing, etc)
recode b17t (999999999=.)
replace b17t=(b17t)/10000
summ b17t, detail
replace b17t=(b17t*12)
recode b19 (999999999=.)
drop if b19>2800000 /*ridiculous missing values*/
replace b19=(b19)/10000
summ b19, detail
replace b19=(b19*12)
recode b21 (99999999=.) (9999999=.)
replace b21=b21/10000
summ b21, detail
recode b22 (9999999=.)
replace b22=(b22)/10000
summ b22, detail
replace b22=(b22*12)
egen other1=rowtotal(b17t b19 b21 b22)
summ other1, detail

*wage/salary secondary employment
recode c08t (999999999=.)
replace c08t=c08t/10000
summ c08t
gen wage2=(c08t*12)
summ wage2, detail

*other income from secondary employment
recode c10t (999999999=.)
replace c10t=c10t/10000
summ c10t
gen other2=(c10t*12)
summ other2, detail

egen incwage=rowtotal(wage1 wage2 extra1 other1 other2)
summ incwage, detail

sort folio
merge folio using geo_ids, uniqusing
tab _merge
drop _merge

keep admin1 admin3 folio pernum factor incwage age male
drop if (folio==. | pernum==.)
sort folio pernum
save temp, replace

*get education

use R04_00, clear
gen folio=nhoga+10*nvivi+10000*upm /*unique household identifier*/
rename l02 pernum

recode ed02 (6=0) (9=.)
label drop ed02
rename ed02 lit
label var lit "literate (y/n)"

recode ed03 (88=.) (99=.)
           
gen educ=.
replace educ=0 if (ed04==0 | ed04==1 | ed04==10) /*none, pre-school, adult literacy*/
replace educ=ed03 if ed04==2 /*primary*/
replace educ=ed03+6 if (ed04>=3 & ed04<=6) /*various secondary ed. specializations*/
replace educ=ed03+12 if (ed04>=7 & ed04<=9) /*teacher training, military ed, university*/  
label var educ "years of education completed"
summ educ, detail

rename fex factor
label var factor "sampling weight"
drop if (folio==. | pernum==.)
sort folio pernum
mmerge folio pernum using temp, type(1:1)
drop _merge

keep incwage folio pernum admin* factor age male educ


**------------Wage/Salary Income Aggregate

keep if incwage!=.
keep if incwage>0

*MEASURE 1: calculate income measures in local prices

rename incwage ywpclp
summ ywpclp, detail
label var ywpclp "wage/salary income - 2001 local prices"

*MEASURE 2: benchmark to PWT (international $)

/*Notes:

*I benchmark income from the census to GDP per worker in constant international $ from
the PWT, using rgdpwok (constant 2000 international $)
*/

*adjust for growth rate of income per worker between 2001 and 2003  - shrank by -0.0710

replace ywpclp=ywpclp*(1-0.0710)

*Calculate conversion factor (need to use sampling weights)

gen double ytpcnpXfactor=ywpclp*factor
egen conspctot=sum(ytpcnpXfactor) 
egen wtot=sum(factor)
gen conspcbar=conspctot/wtot
drop conspctot wtot ytpcnpXfactor
summ conspcbar

gen convertgdp=(12237.23029)/conspcbar
summ convertgdp

gen ywpcip=ywpclp*convertgdp
summ ywpcip, detail
label var ywpcip "wage/salary income - international dollars"
rename ywpcip yepcip
rename ywpclp yepclp

drop convertgdp conspcbar

replace admin3=1 if admin1==0 /*Asuncion - admin3 seems to give something akin to
	neighborhods in Asuncion, which I cannot identify with my GIS data*/

label var admin1 "department"
label var admin3 "municipality"
label var folio "household identifier"

sort admin1 admin3
merge admin1 admin3 using $aejfinalcode/pop00PA, uniqusing
tab _merge
drop if _merge==2 /*in map, not in survey*/
drop _merge

*There are some municipalities in the survey that are not on the gis map
*Either there is an error in the GIS map, or the missing municipalities
*have split since the gis map was created. I assign them 
*the median population of their respective departments.

egen popbar=median(pop00), by(admin1)
replace pop00=popbar if pop00==.
drop popbar


sort admin1 admin3
save temp, replace

*generate municipality weights
gen obs=1
collapse (sum) obs (mean) pop00, by(admin1 admin3)
egen double total=sum(pop00)

gen ww=1000*((pop00/obs)/total)
keep ww admin1 admin3 obs
sort admin1 admin3 
merge admin1 admin3 using temp, uniqmaster
tab _merge
drop _merge
sum ww
label var ww "weights"

*generate country ID
gen cntry="PA"

d
summ
sort folio
save $aejfinalcode/ywage_paraguay, replace


***********************************************************************************
*Peru (ENAHO, 2001)
***********************************************************************************


global thebulkdir = "INSERT DIRECTORY WITH DATA FILES FOR PE HERE"
cd $thebulkdir


/*Data files used
		enaho01a_2001iv_500
		enaho01a_2001iv_300
		
*Data files created as final product
		yearn_peru
*/

**Get gender and age data

use enaho01a_2001iv_300, clear
gen folio = conglome + vivienda + hogar

rename eda300 age 
gen male=sex300
recode male (2=0)

rename codperso pernum

**Get education data

/*fix the discrepancy between whether info recorded as ano (p301b) or grado (p301c)*/
replace p301b=p301c if p301b==0
replace p301b=0 if (p301b==. & p301c==.)
gen educ=.

/*recode for those with incomplete or complete primary*/
replace educ=p301b if (p301a==1)
replace educ=p301b if (p301a==2)
replace educ=p301b if (p301a==3)
replace educ=p301b if (p301a==4)

/*Appears that primary education used to be typically 5 years but within the 
past 30 or so years has become typically six years. Generate a var by district
that is mean # of years of primary education*/
egen mpeduc1=mean(p301b) if p301a==4, by (ubigeo)
tab mpeduc1
egen mpeduc=mean(mpeduc1), by (ubigeo)
replace mpeduc=5.5 if mpeduc==.
drop mpeduc1

/*recode for those with complete or incomplete secondary*/
replace educ=mpeduc+p301b if (p301a==5)
replace educ=mpeduc+p301b if (p301a==6)

/*recode for those with complete or incomplete postsecondary*/
replace educ=mpeduc+5+p301b if (p301a==7)
replace educ=mpeduc+5+p301b if (p301a==8)
replace educ=mpeduc+5+p301b if (p301a==9)
replace educ=mpeduc+5+p301b if (p301a==10)

/*recode educ for those with postgrado*/
replace educ=mpeduc+10+p301b if (p301a==11)

*generate geographic codes
gen admin1=substr(ubigeo, 1, 2)
gen admin2=substr(ubigeo, 3, 2)
gen admin3=substr(ubigeo, 5, 2)
destring admin1, replace
destring admin2, replace
destring admin3, replace


keep if educ<.

replace admin1=15 if admin1==7 /*recoding Callao*/


keep folio age male pernum admin1 admin2 admin3 educ
sort folio pernum
save temp, replace


**Get income data

use enaho01a_2001iv_500, clear
gen folio = conglome + vivienda + hogar
destring ubigeo, replace
replace ubigeo=ubigeo + 1000000
tostring ubigeo, replace
gen admin1=substr(ubigeo, 2, 2)
gen admin2=substr(ubigeo, 4, 2)
gen admin3=substr(ubigeo, 6, 2)

destring admin1, replace
destring admin2, replace
destring admin3, replace

rename codperso pernum
drop factor
rename fac500 factor

label var folio "household identifier"
label var pernum "person identifier"
label var admin1 "department"
label var admin2 "province"
label var admin3 "district"
label var factor "sampling weight"


***FIRST OCCUPATION - WAGE INCOME

recode p523 (1=261) (2=52) (3=24) (4=12)
gen cash1=p524a1*p523 /*monetary income*/

foreach X of num 1/6 {
	recode p529`X'a (1=261) (2=52) (3=24) (4=12)  (6=4) 
	recode p529`X'a (5=6) (7=2) (8=1)
	replace  p529`X'b= p529`X'b* p529`X'a
}

egen inkind1=rowtotal(p5291b p5292b p5293b p5294b p5295b p5296b)
summ inkind1, detail

egen inc1=rowtotal(cash1 inkind1)
summ inc1, detail

***FIRST OCCUPATION - SELF-EMPLOYMENT

replace p533=p533*12 /*earnings*/
replace p536=p536*12 /*auto-consumption*/

egen self1=rowtotal(p533 p536)
summ self1, detail

*SECONDARY OCCUPATION - WAGE INCOME

gen cash2 =p538a1*12

foreach X of num 1/6 {
	recode p540`X'a (1=261) (2=52) (3=24) (4=12)  (6=4) 
	recode p540`X'a (5=6) (7=2) (8=1)
	replace  p540`X'b= p540`X'b* p540`X'a
}

egen inkind2=rowtotal(p5401b p5402b p5403b p5404b p5405b p5406b)
summ inkind2, detail

egen inc2=rowtotal(cash2 inkind2)
summ inc2, detail

*SECONDARY OCCUPATION - SELF-EMPLOYMENT INCOME

replace p541a =p541a*12 /*earnings*/
replace p543=p543*12 /*autoconsumption*/

egen self2=rowtotal(p541a p543) 

*overtime income per year is p544t

egen incwage=rowtotal(inc1 inc2 p544t)
egen incearn=rowtotal(inc1 self1 inc2 self2 p544t)

keep incearn folio pernum admin* factor


sort folio pernum
merge folio pernum using temp, unique
tab _merge
drop _merge

*label vars
label var male "1=male,0=female"
label var age "age (years)"
label var educ "years of schooling"

***------------Labor Income Aggregate

keep if incearn!=.
keep if incearn>0

*MEASURE 1: calculate income measures in local prices

rename incearn yepclp
summ yepclp, detail
label var yepclp "earned income - 2001 local prices"

*MEASURE 2: benchmark to PWT (international $)

/*Notes:

*I benchmark income from the census to GDP per worker in constant international $ from
the PWT, using rgdpwok (constant 2000 international $)
*/

*adjust for growth rate of income per worker between 2001 and 2003 

replace yepclp=yepclp*(1+0.0242)

*Calculate conversion factor (need to use sampling weights)

gen double ytpcnpXfactor=yepclp*factor
egen conspctot=sum(ytpcnpXfactor) 
egen wtot=sum(factor)
gen conspcbar=conspctot/wtot
drop conspctot wtot ytpcnpXfactor
summ conspcbar

gen convertgdp=(11082.03207)/conspcbar
summ convertgdp

gen yepcip=yepclp*convertgdp
summ yepcip, detail
label var yepcip "earned income - international dollars"

drop convertgdp conspcbar

label var folio "household identifier"


keep if admin1<.
keep if admin3<.

replace admin1=15 if admin1==7 /*code Callao as part of Lima so that have gis data
		for this small port*/


label var admin1 "department identifier"
label var admin2 "province identifier" 

sort admin1 admin2 admin3
merge admin1 admin2 admin3 using $aejfinalcode/pop00PE, uniqusing
tab _merge
drop if _merge==2 /*in gis, not in sample*/

drop _merge

*There's one municipality in Madre de Dios department (in the Amazon) that's not in the GIS
*map. Assign it the province-median population. 

egen popbar=median(pop00), by(admin2)
replace pop00=popbar if pop00==.
drop popbar

sort admin1 admin3
save temp, replace

*generate municipality weights
gen obs=1
collapse (sum) obs (mean) pop00, by(admin1 admin3)
egen double total=sum(pop00)

gen ww=1000*((pop00/obs)/total)
keep ww admin1 admin3 obs
sort admin1 admin3 
merge admin1 admin3 using temp, uniqmaster
tab _merge
drop _merge
sum ww

*generate country ID
gen cntry="PE"

d
summ
sort folio
save $aejfinalcode/yearn_peru, replace

***********************************************************************************
*Prepare data on wage and labor income for Uruguay
***********************************************************************************

global thebulkdir = "INSERT DIRECTORY WITH DATA FILES FOR UY HERE"
cd $thebulkdir


/*Data files used
	pers14omas.dta
	persona
	
*Data files created as final product
	yearn_uruguay
*/

**get age and gender data


use persona, clear

*generate household identifier
destring hog, replace
destring viv, replace
destring dpto, replace
gen double folio=hog+10*viv+100000*dpto
tostring folio, replace
gen male=d22
recode male (2=0)
rename d23 age
rename per pernum

**get education data

gen educ=.
replace educ=0 if (d271==1) /*pre-school*/
replace educ=d272 if (d271==2) /*primary*/
replace educ=d272+6 if (d271==3 | d271==4) /*secondary, technical*/
replace educ=d272+12 if (d271==6 | d271==7 | d271==8) /*teacher's school, university, military school*/
replace educ=d272+16 if (d271==5) /*masters/phd*/
label var educ "years of schooling"
summ educ, detail

*label variables

label var educ "years of schooling"
label var male "1=male, 0=female"
label var age "age (years)"

keep folio age male pernum educ
sort folio pernum
save temp, replace

**get income data

use pers14omas.dta, clear
destring hog, replace
destring viv, replace
destring dpto, replace
gen double folio=hog+10*viv+100000*dpto
tostring folio, replace
label var folio "household identifier"

rename facexp factor
label var factor "sampling weight"

rename per pernum
label var pernum "individual identifier"

*aggregate various components of wage/salary income (i.e. wage, varous payments in kind
*tips, overtime, etc)

foreach X in f50111  f50121 f50131 f50141 f50151 f50161 f50171 f50181 f50191 f501101 f501111 f501121 /*
	*/f501131 f501141 f50221 f50231 f50241 f50251 f50261 f50311 f50321 f50212 {
		 replace `X'=`X'*12
}

egen incwage=rowtotal (f50111  f50121 f50131 f50141 f50151 f50161 f50171 f50181 f50191 f501101 f501111 f501121 /*
	*/f501131 f501141 f50221 f50231 f50241 f50251 f50261 f50311 f50321 f50212)
summ incwage, detail

foreach X in f53111 f53121 f53311 {
	recode `X' .=0
	replace `X'=`X'*12
}

gen incself=f53111 + f53121 - f53311 /*retained earnings + consumption in kind - taxes*/
summ incself, detail

egen incearn=rowtotal(incwage incself)
summ incearn, detail

gen admin1=dpto
destring admin1, replace

keep admin1 folio pernum factor incearn 
sort folio pernum
mmerge folio pernum using temp, type(1:1)
drop _merge

***------------Labor Income Aggregate

keep if incearn!=.
keep if incearn>0

*MEASURE 1: calculate income measures in local prices

rename incearn yepclp
summ yepclp, detail
label var yepclp "earned income - 2006 local prices"

*MEASURE 2: benchmark to PWT (international $)

/*Notes:

*I benchmark income from the census to GDP per worker in constant international $ from
the PWT, using rgdpwok (constant 2000 international $)
*/

/*Using these data from the WDI, Uruguayan income per capita grew by (a very high) 
0.2402 between 2003 and 2006. */

replace yepclp=yepclp*(1-0.2402)

*Calculate conversion factor (need to use sampling weights)

gen double ytpcnpXfactor=yepclp*factor
egen conspctot=sum(ytpcnpXfactor) 
egen wtot=sum(factor)
gen conspcbar=conspctot/wtot
drop conspctot wtot ytpcnpXfactor
summ conspcbar

gen convertgdp=(19491.32458)/conspcbar
summ convertgdp

gen yepcip=yepclp*convertgdp
summ yepcip, detail
label var yepcip "earned income - international dollars"

drop convertgdp conspcbar

destring admin1, replace

label var admin1 "province"
label var folio "household identifier"


sort admin1
merge admin1 using $aejfinalcode/pop00UY, uniqusing
tab _merge
keep if _merge==3 /*The province Cerro Largo is not in my GIS map*/
drop _merge

sort admin1
save temp, replace

*generate municipality weights
gen obs=1
collapse (sum) obs (mean) pop00, by(admin1)
egen double total=sum(pop00)

gen ww=1000*((pop00/obs)/total)
keep ww admin1 obs
sort admin1 
merge admin1 using temp, uniqmaster
tab _merge
drop _merge
sum ww
label var ww "weights"

*generate country ID
gen cntry="UY"

d
summ
sort folio
save $aejfinalcode/yearn_uruguay, replace



***********************************************************************************
*Prepare data from the 5% PUMS of the 2000 U.S. census
***********************************************************************************


global thebulkdir = "INSERT DIRECTORY WITH DATA FILES FOR US HERE"
cd $thebulkdir


/*Data files used
		us_pums00
		
*Data files created as final product
		yearn_us
*/

		
*Prepare Income, education, and demogrpahic data

use /disk/bulkr/dellm/growth_empirics/ethnic/UScensus, clear

*give variables more descriptive names
label drop _all
rename statefip admin1
rename puma admin3
rename perwt factor
rename numprec pernum

keep admin1 admin3 serial pernum factor incearn age sex educrec 

rename educrec educ 
recode educ (0=.) (1=0) (3=8) (4=9) (5=10) (6=11) (7=12) (8=14) (9=16) (2=4) 
rename sex male
recode male (2=0) (9=0)

*label variables

label var educ "years of schooling"
label var age "age (years)"
label var male "male=1, female=0"

recode incearn (999998=.) (999999=.)

***------------Labor Income Aggregate

keep if incearn!=.
keep if incearn>0

*MEASURE 1: calculate income measures in local prices

rename incearn yepclp
summ yepclp, detail
label var yepclp "earned income - 2000 local prices"

*MEASURE 2: benchmark to PWT (international $)

/*Notes:

*I benchmark income from the census to GDP per worker in constant international $ from
the PWT, using rgdpwok (constant 2000 international $)
*/

*adjust for growth rate of income per worker between 2000 and 2003 

replace yepclp=yepclp*(1+0.0117)

*Calculate conversion factor (need to use sampling weights)

gen double ytpcnpXfactor=yepclp*factor
egen conspctot=sum(ytpcnpXfactor) 
egen wtot=sum(factor)
gen conspcbar=conspctot/wtot
drop conspctot wtot ytpcnpXfactor
summ conspcbar

gen convertgdp=(67865.44198)/conspcbar
summ convertgdp

gen yepcip=yepclp*convertgdp
summ yepcip, detail
label var yepcip "earned income - international dollars"

drop convertgdp conspcbar

label var admin1 "state identifier"
label var admin3 "puma identifier"

sort admin1 admin3
merge admin1 admin3 using $aejfinalcode/pop00US, uniqusing
tab _merge
drop if _merge==2 /*in gis, not in sample*/
drop _merge

sort admin1 admin3
save temp, replace

*generate municipality weights
gen obs=1
collapse (sum) obs (mean) pop00, by(admin1 admin3)
egen double total=sum(pop00)

gen ww=1000*((pop00/obs)/total)
keep ww admin1 admin3 obs
sort admin1 admin3 
merge admin1 admin3 using temp, uniqmaster
tab _merge
drop _merge
sum ww
label var ww "weight"

*generate country ID
gen cntry="US"

d
summ

save $aejfinalcode/yearn_us, replace



***********************************************************************************
*Venezuela (10% PUMS of the 2001 Venezuelan census)
***********************************************************************************

global thebulkdir = "INSERT DIRECTORY WITH DATA FILES FOR VE HERE"
cd $thebulkdir


/*Data files used
		VEcensus
		
*Data files created as final product
		yearn_venezuela
*/

		
************************
*Prepare Income Data
************************
use VEcensus, clear

*give variables more descriptive names

rename stateve admin1
rename munive admin3
rename wtper factor

rename yrschl educ
drop if educ>=90

rename sex male
recode male (2=0)

*label variables
label var male "1=male, 0=female"
label var educ "years of schooling"
label var age "age (years)"
*----recode missing values

recode incearn (99999998=.) (99999999=.)

summ incearn, detail

*convert to annual reference period
replace incearn=incearn*12


***------------Labor Income Aggregate

keep if incearn!=.
keep if incearn>0

*MEASURE 1: calculate income measures in local prices

rename incearn yepclp
summ yepclp, detail
label var yepclp "earned income - 2001 local prices"

*MEASURE 2: benchmark to PWT (international $)

/*Notes:

*I benchmark income from the census to GDP per worker in constant international $ from
the PWT, using rgdpwok (constant 2001 international $)
*/

*adjust for growth rate of income per worker between 2001 and 2003 
****This isn't a mistake. According to the PWT, the Venezuelan economy actually shrunk
*this much between 2001 and 2003

replace yepclp=yepclp*(1-0.1973)

*Calculate conversion factor (need to use sampling weights)

gen double ytpcnpXfactor=yepclp*factor
egen conspctot=sum(ytpcnpXfactor) 
egen wtot=sum(factor)
gen conspcbar=conspctot/wtot
drop conspctot wtot ytpcnpXfactor
summ conspcbar

gen convertgdp=(14847.8984)/conspcbar
summ convertgdp

gen yepcip=yepclp*convertgdp
summ yepcip, detail
label var yepcip "earned income - international dollars"

drop convertgdp conspcbar

label var admin1 "state identifier"
label var admin3 "municipality identifier"
/*unfortunately not all the data are merging with GIS data because of missing GIS
		data for the islands*/

keep serial pernum educ male age yepcip yepclp admin1 admin3

*some small, perhaps recently formed munics don't appear in my gis
*data. Combine them with the "rural" municipality for each state

replace admin3=	399	if admin3==	303
replace admin3=	399	if admin3==	319
replace admin3=	599	if admin3==	503
replace admin3=	599	if admin3==	507
replace admin3=	599	if admin3==	519
replace admin3=	599	if admin3==	520
replace admin3=	799	if admin3==	706
replace admin3=	899	if admin3==	806
replace admin3=	899	if admin3==	807
replace admin3=	899	if admin3==	810
replace admin3=	899	if admin3==	812
replace admin3=	1099	if admin3==	1005
replace admin3=	1599	if admin3==	1522
replace admin3=	2099	if admin3==	2028
replace admin3=	2099	if admin3==	2030
replace admin3=	2199	if admin3==	2114
replace admin3=	2199	if admin3==	2121
replace admin3=	2299	if admin3==	2204
replace admin3=	2299	if admin3==	2205
replace admin3=	2299	if admin3==	2214
replace admin3=	2299	if admin3==	2215
replace admin3=	2399	if admin3==	2306
replace admin3=	2299	if admin3==	2317 	
replace admin3=	2299	if admin3==	2319 	
replace admin3=	2299	if admin3==	2322 	

*separate munic and state codes so that they match the population data
replace admin3=admin3+10000
tostring admin3, g(temp)
drop admin3 admin1
gen admin1=substr(temp, 2, 2)
gen admin3=substr(temp, 4, 2)
drop temp
destring admin1, replace
destring admin3, replace
tab admin1
summ admin3
sort admin1 admin3
merge admin1 admin3 using $aejfinalcode/pop00VE, uniqusing
tab _merge
drop _merge


*899 is the unit that's not merging. After matching all the municipalities in admin1=8
*that are identified in the census, there are none left in the GIS map to form
*the code 99 (small municipalities combined in the census for confidentiality purposes).
*Either there is an error in the GIS map, or the small municipalities that are 
*referenced to 899 have split since the gis map was created. I assign them 
*the median population of the state Caraboba (admin1==8).

egen popbar=median(pop00), by(admin1)
replace pop00=popbar if pop00==.
drop popbar

sort admin1 admin3
save temp, replace

*generate municipality weights
gen obs=1
collapse (sum) obs (mean) pop00, by(admin1 admin3)
egen double total=sum(pop00)

gen ww=1000*((pop00/obs)/total)
keep ww admin1 admin3 obs
sort admin1 admin3 
merge admin1 admin3 using temp, uniqmaster
tab _merge
drop _merge
sum ww

*label vars
label var ww "weights"
label var admin1 "state identifier"
label var admin3 "municipality identifier"

*generate country ID
gen cntry="VE"

d
summ


sort pernum
save $aejfinalcode/yearn_venezuela, replace




